import time
#Class with the methods that check that the inputs are specifically what the code needs 
#All methods of this class do basically the same, a loop that only stops until the input is correct
class Check:
    
    def __init__(self): #init all attributes to none
        self.item = None 
        self.resp = None
        self.check_in = None
        self.p = None

    
    def error(self, check_in , valid_ans=[]): #checks inputs are what expected(valid_ans)
        self.resp = input(check_in)
        while True:
            if self.resp.lower() in valid_ans :
                return self.resp
            else:
                  self.resp = input(f"\nPlease enter {valid_ans} as your answer: ") 
                  
                  
    def error_act(self, valid_ans): #checks and follows a message and an action 
        while True:
            if self.item.lower() in valid_ans:
                message, action = valid_ans [self.item.lower()]
                print(message)
                action()
                return self.item
            else:
                k_valid_ans = list(valid_ans.keys())
                self.item = input(f"\nPlease enter {k_valid_ans} as your answer: ")
                
                
    def mandatory(self, prompt): #makes sure is not empty
        while True:
            self.p = input(prompt)
            if len(self.p) == 0:
                print("This cannot be empty")  
            else:
                return self.p


    def interger(self,to_check): #an integer needed as input
        while True:
            try :
                to_check = int(to_check)
                return to_check
            except :
                print("Your answer needs to be a valid integer")
                time.sleep(1)
                to_check = input("Please enter a number as your answer:")



from newquiz.enter_input import Enter


class Start(Enter):
    def __init__(self):
        self.quiz_list = []
    
    def start_game(self):
        print("\n------<3------\nWelcome!!")
        self.item = input("What do you want to do?\na)Play an existing quiz\nb)Create a new game\n")
        self.error_act(valid_ans = {
            "a": ("Perfect", self.display_quiz),
            "b": ("Perfect", self.start_create)
            })
       
    






from setuptools import setup, find_packages
import codecs
import os



VERSION = '0.0.1'
DESCRIPTION = 'Quiz creator and displayer'
LONG_DESCRIPTION = 'Advanced coding skills project: A game of a quiz that allows you to create it and save it, and play your own and other saved quizzes'

# Setting up
setup(
    name="quiz_project",
    version=VERSION,
    author="Mariana Aguerrevere",
    author_email="<aamariana1907@gmail.com>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['json','time'],
    keywords=['python', 'quiz', 'creator','display', 'game']
)


import json
import time
from play.check_input import Check


class Display(Check):
    def __init__(self):
        pass#no needed


    def read_json(self): #reads json file
        with open("quiz.json", "r") as file:
            data = json.load(file) 
        return data
    
    
    def find_quiz_by_title(self, title): #search a specific quiz by title given in display_quiz()
        data = self.read_json()
        for quiz in data:
            if title in quiz:
                return quiz[title]
        return None #return none if no quiz has that title


    def show_quiz(self, quiz): #prints the quiz and saves score
        print("\nQuiz:\n")
        score = 0
        for item in quiz: #goes trough each Q
            print("---<3---")
            print(f"Question: {item['question']}")
            for index, option in enumerate(item['options'], 1): #arranges the opt of ans to print 
                print(f"{index}. {option}")
            valid_answers = [str(i) for i in range(1, len(item['options']) + 1)]#a list of all the possible ans since the amount of opt is define by the user when creating the quiz
            answer_index = self.error("Enter the number of your answer: ", valid_ans=valid_answers)#method from Check to only accept the criteria of valid_answers
            if item['options'][int(answer_index) - 1] == item['answer']:#checks if it is the same as the correct ans so adds the score
                score += 1
        print(f"Your score: {score}/{len(quiz)}")
        time.sleep(2)
        print("---<3---\nHope you liked it and come back later <3\n---<3---")
        time.sleep(4)

    
    def display_quiz(self):
        data = self.read_json()#gets quizzes
        while True:
            time.sleep(1)
            title = input("Enter the full title of the quiz you want to play or press Enter to see all the quizzes availables: ")#ask for title desired
            quiz = self.find_quiz_by_title(title)#search it in json file
            if quiz is not None:
                self.show_quiz(quiz)#goes to print
                break
            else:
                print(f"No quiz found with the title '{title}'")
                available_titles = [list(quiz.keys())[0] for quiz in data]#shows all the quizzes' titles
                time.sleep(1)
                print(f"Available quiz titles: {', '.join(available_titles)}")
